copyWith property
Whether to generate a copyWith or not
If null, picks up the default values from the project's build.yaml.
If that value is null too, defaults to true.
Implementation
final bool? copyWith;
Whether to generate a copyWith or not
If null, picks up the default values from the project's build.yaml.
If that value is null too, defaults to true.
final bool? copyWith;